#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-path-z-os-string-compat
version:              0.9.6
package-name:         path
lib-name:             os-string-compat
id:                   path-0.9.6-FudslSfvPYl4DLZGz3z8BL-os-string-compat
key:                  path-0.9.6-FudslSfvPYl4DLZGz3z8BL-os-string-compat
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  474646c4bf299a4886f94b1f155eb481
exposed-modules:
    System.OsString.Compat.Posix System.OsString.Compat.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-FudslSfvPYl4DLZGz3z8BL-os-string-compat
depends:              base-4.18.2.1 filepath-1.4.300.1
haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.6
visibility:           public
id:                   path-0.9.6-7raF4tLYHpHKU533QPH3ar
key:                  path-0.9.6-7raF4tLYHpHKU533QPH3ar
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  0f00437739ea281d54c03c9753a7aa9d
exposed:              True
exposed-modules:
    OsPath OsPath.Internal OsPath.Internal.Posix
    OsPath.Internal.Windows OsPath.Posix OsPath.Windows Path
    Path.Internal Path.Internal.Posix Path.Internal.Windows Path.Posix
    Path.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-7raF4tLYHpHKU533QPH3ar
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    path-0.9.6-FudslSfvPYl4DLZGz3z8BL-os-string-compat
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

